#!/bin/bash
#
# Copyright (c) 2014 OpenElectrons.com
# SmartUPS installation script.
# for more information about SmartUPS,  please visit:
# http://www.openelectrons.com/pages/33
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

apt-get install python-smbus

sed -i 's/blacklist i2c-bcm2708/#blacklist i2c-bcm2708/g' /etc/modprobe.d/raspi-blacklist.conf

grep i2c-bcm2708 /etc/modules > /dev/null
if [ $? == 0 ]
then
	echo "i2c-bcm2708 already installed"
else
	echo 'i2c-bcm2708' >> /etc/modules
fi

grep i2c-dev /etc/modules > /dev/null
if [ $? == 0 ]
then
	echo "i2c-dev already installed"
else
	echo 'i2c-dev' >> /etc/modules
fi


echo "-----------------------------"
echo "I2C installation completed   "
echo "-----------------------------"

#
# configure i2c bus with correct baud rate.
#
sudo bash -c "echo options i2c_bcm2708 baudrate=50000 > /etc/modprobe.d/i2c.conf"

#
#  check that user has required files.
#

if [ -e /usr/local/sbin/SmartUPS ]
then
    echo "Updating driver files..."
    pid=`ps -ef | grep SmartUPS | grep -v grep | cut -c 10-15`
    kill -9 $pid
    sudo rm -f /usr/local/sbin/SmartUPS
    sudo cp SmartUPS /usr/local/sbin
else
    echo "Copying driver files..."
    sudo cp SmartUPS /usr/local/sbin
fi

if [ -e /etc/init.d/SmartUPS.sh ]
then
    echo "Updating startup files..."
    sudo rm -f /etc/init.d/SmartUPS.sh
    sudo cp SmartUPS.sh /etc/init.d
else
    echo "Copying startup files..."
    sudo cp SmartUPS.sh /etc/init.d
fi

if [ -e /usr/lib/arm-linux-gnueabihf/lxpanel/plugins/SmartUPS.so ]
then
    echo "Updating plugin files..."
    sudo rm -rf /usr/lib/arm-linux-gnueabihf/lxpanel/plugins/SmartUPS.so
    sudo cp SmartUPS.so /usr/lib/arm-linux-gnueabihf/lxpanel/plugins
else
    echo "Copying plugin files..."
    sudo cp SmartUPS.so /usr/lib/arm-linux-gnueabihf/lxpanel/plugins
fi

if [ -e /etc/SmartUPS/SmartUPS.cfg ]
then  
    echo "Updating files and setting permissions..."
    sudo rm -rf /etc/SmartUPS/SmartUPS.cfg
    sudo cp SmartUPS.cfg /etc/SmartUPS
    sudo chmod 777 /etc/SmartUPS/SmartUPS.cfg
else
    echo "Copying files and setting permissions..."
    sudo mkdir /etc/SmartUPS
    sudo cp SmartUPS.cfg /etc/SmartUPS
    sudo chmod 777 /etc/SmartUPS/SmartUPS.cfg
fi

if [ -e /etc/SmartUPS/OEmessage.bash ]
then  
    echo "Updating files and setting permissions..."
    sudo rm -rf /etc/SmartUPS/OEmessage.bash
    sudo cp OEmessage.bash /etc/SmartUPS
    sudo chmod 777 /etc/SmartUPS/OEmessage.bash
else
    echo "Copying files and setting permissions..."
    sudo cp OEmessage.bash /etc/SmartUPS
    sudo chmod 777 /etc/SmartUPS/OEmessage.bash
fi


if [ -e /usr/local/bin/upspanel ]
then
    echo "Updating executable files..."
    sudo cp upspanel /usr/local/bin
    sudo chmod 111 /usr/local/bin/upspanel
else
    echo "Copying executable files..."
    sudo cp upspanel /usr/local/bin
    sudo chmod 111 /usr/local/bin/upspanel
fi

if [ -e /usr/bin/pip ]
then
    echo "pip already installed"
else    
    echo "Installing Software, may take several minutes..."
    yes | sudo apt-get -qq install python-pip
fi

if [ -e /usr/local/lib/python2.7/dist-packages/smartups.py ]
then
    echo "Updating SmartUPS library..."
    sudo pip install -qq SmartUPS
else
    echo "Installing libraries..."
    sudo pip install -qq SmartUPS
fi

if [ -e /usr/lib/wx ]
then
    echo "wx already installed"
else    
    echo "Installing Software, may take several minutes..."
    yes | sudo apt-get -qq install python-wxgtk2.8
fi

#
# insert into startup scripts for subsequent use
#

sudo update-rc.d SmartUPS.sh defaults 94 06

#
#  start the SmartUPS for this time use
#

sudo /etc/init.d/SmartUPS.sh start > /dev/null

echo "-----------------------------"
echo "SmartUPS Install completed     "
echo "Reboot for changes to take effect"
echo "-----------------------------"
